@@ -1,16 +1,10 @@
-import typing
-
 import enum
+import typing
 
 import pandas as pd
 import pydantic
 
-from retrack.nodes.base import (
-    BaseNode,
-    InputConnectionModel,
-    NodeKind,
-    OutputConnectionModel,
-)
+from retrack.nodes.base import BaseNode, InputConnectionModel, OutputConnectionModel
 
 ###############################################################
 # Check Metadata Models
@@ -60,15 +54,19 @@ class Check(BaseNode):
     inputs: CheckInputsModel
     outputs: CheckOutputsModel
 
-    def run(
+    async def run(
         self,
         input_value_0: pd.Series,
         input_value_1: pd.Series,
     ) -> typing.Dict[str, pd.Series]:
         if self.data.operator == CheckOperator.EQUAL:
-            return {"output_bool": input_value_0 == input_value_1}
+            return {
+                "output_bool": input_value_0.astype(str) == input_value_1.astype(str)
+            }
         elif self.data.operator == CheckOperator.NOT_EQUAL:
-            return {"output_bool": input_value_0 != input_value_1}
+            return {
+                "output_bool": input_value_0.astype(str) != input_value_1.astype(str)
+            }
         elif self.data.operator == CheckOperator.GREATER_THAN:
             return {
                 "output_bool": input_value_0.astype(float) > input_value_1.astype(float)
