@@ -2,6 +2,7 @@ import pandas as pd
 import pydantic
 
 from retrack.nodes.base import BaseNode, InputConnectionModel, OutputConnectionModel
+from retrack.utils import transformers
 
 ################################################
 # EndsWithAny Inputs Outputs
@@ -26,5 +27,6 @@ class EndsWithAny(BaseNode):
     inputs: EndsWithAnyInputsModel
     outputs: EndsWithAnyOutputsModel
 
-    def run(self, input_value: pd.Series, input_list: pd.Series) -> pd.Series:
-        return {"output_bool": input_value.str.endswith(tuple(input_list.to_list()))}
+    async def run(self, input_value: pd.Series, input_list: pd.Series) -> pd.Series:
+        input_list = transformers.to_list(input_list)
+        return {"output_bool": input_value.str.endswith(tuple(input_list))}
