@@ -7,6 +7,7 @@ from retrack.nodes.base import (
     BaseNode,
     InputConnectionModel,
     NodeKind,
+    NodeMemoryType,
     OutputConnectionModel,
 )
 
@@ -36,8 +37,11 @@ class If(BaseNode):
     def kind(self) -> NodeKind:
         return NodeKind.FILTER
 
-    def run(self, input_bool: pd.Series) -> typing.Dict[str, pd.Series]:
+    async def run(self, input_bool: pd.Series) -> typing.Dict[str, pd.Series]:
         return {
-            f"output_then_filter": input_bool,
-            f"output_else_filter": ~input_bool,
+            "output_then_filter": input_bool.astype(bool),
+            "output_else_filter": ~input_bool.astype(bool),
         }
+
+    def memory_type(self) -> NodeMemoryType:
+        return NodeMemoryType.FILTER
